@@ -6,23 +6,36 @@ import sys
 from sqlalchemy.engine import create_engine
 from sqlalchemy.schema import MetaData
 
-from sqlacodegen.codegen import generate_model_code
+from sqlacodegen.codegen import CodeGenerator
+import sqlacodegen
 
 
 def main():
     parser = argparse.ArgumentParser(description='Generates SQLAlchemy model code from an existing database.')
-    parser.add_argument('url', help='SQLAlchemy url to the database')
+    parser.add_argument('url', nargs='?', help='SQLAlchemy url to the database')
+    parser.add_argument('--version', action='store_true', help="print the version number and exit")
     parser.add_argument('--schema', help='load tables from an alternate schema')
     parser.add_argument('--tables', help='tables to process (comma-separated, default: all)')
     parser.add_argument('--noviews', action='store_true', help="ignore views")
     parser.add_argument('--noindexes', action='store_true', help='ignore indexes')
     parser.add_argument('--noconstraints', action='store_true', help='ignore constraints')
+    parser.add_argument('--nojoined', action='store_true', help="don't autodetect joined table inheritance")
+    parser.add_argument('--noinflect', action='store_true', help="don't try to convert tables names to singular form")
     parser.add_argument('--outfile', type=argparse.FileType('w'), default=sys.stdout,
                         help='file to write output to (default: stdout)')
     args = parser.parse_args()
 
+    if args.version:
+        print(sqlacodegen.version)
+        return
+    if not args.url:
+        print('You must supply a url\n', file=sys.stderr)
+        parser.print_help()
+        return
+
     engine = create_engine(args.url)
     metadata = MetaData(engine)
     tables = args.tables.split(',') if args.tables else None
     metadata.reflect(engine, args.schema, not args.noviews, tables)
-    print(generate_model_code(metadata, args.noindexes, args.noconstraints), file=args.outfile)
+    generator = CodeGenerator(metadata, args.noindexes, args.noconstraints, args.nojoined, args.noinflect)
+    generator.render(args.outfile)
